@@ -40,6 +40,7 @@ def hbe(coeff, x):
 
 
     Parameters:
+    -----------
     coeff (list or numpy array): The coefficient vector. 
                                  All values must be greater than 0.
 
@@ -48,12 +49,14 @@ def hbe(coeff, x):
 
 
     Returns:
+    --------
     The cdf of the x value(s). It is returned as the same type as x, 
     i.e. if x is a list, it is returned as a list; if x is a numpy array
     it is returned as a numpy array.
 
 
     Details:
+    --------
      * Note that division assumes Python 3, so may not work with Python 2.
      * Depends on numpy libary for the arrays.
      * If lists are passed, they are converted to numpy arrays (and back again).
@@ -61,6 +64,7 @@ def hbe(coeff, x):
 
 
     Examples:
+    ---------
     #Examples taken from Table 18.6 in N. L. Johnson, S. Kotz, N. Balakrishnan.
     #Continuous Univariate Distributions, Volume 1, John Wiley & Sons, 1994.
 
@@ -86,6 +90,7 @@ def hbe(coeff, x):
 
 
     References:
+    -----------
      * P. Hall. Chi squared approximations to the distribution of a
        sum of independent random variables. The Annals of
        Probability, 11(4):1028-1036, 1983.
@@ -143,6 +148,7 @@ def sw(coeff, x):
 
 
     Parameters:
+    -----------
     coeff (list or numpy array): The coefficient vector. 
                                  All values must be greater than 0.
 
@@ -151,12 +157,14 @@ def sw(coeff, x):
 
 
     Returns:
+    --------
     The cdf of the x value(s). It is returned as the same type as x, 
     i.e. if x is a list, it is returned as a list; if x is a numpy array
     it is returned as a numpy array.
 
 
     Details:
+    --------
      * Note that division assumes Python 3, so may not work with Python 2.
      * Depends on numpy libary for the arrays.
      * If lists are passed, they are converted to numpy arrays (and back again).
@@ -164,6 +172,7 @@ def sw(coeff, x):
 
 
     Examples:
+    ---------
     #Examples taken from Table 18.6 in N. L. Johnson, S. Kotz, N. Balakrishnan.
     #Continuous Univariate Distributions, Volume 1, John Wiley & Sons, 1994.
 
@@ -189,6 +198,7 @@ def sw(coeff, x):
 
 
     References:
+    -----------
      * B. L.Welch. The significance of the difference between two
        means when the population variances are unequal.
        Biometrika, 29(3/4):350-362, 1938.
@@ -244,6 +254,7 @@ def wf(coeff, x):
     random variables with the Wood F (WF) method.
 
     Parameters:
+    -----------
     coeff (list or numpy array): The coefficient vector. 
                                  All values must be greater than 0.
 
@@ -252,18 +263,21 @@ def wf(coeff, x):
 
 
     Returns:
+    --------
     The cdf of the x value(s). It is returned as the same type as x, 
     i.e. if x is a list, it is returned as a list; if x is a numpy array
     it is returned as a numpy array.
 
 
     Details:
+    --------
      * Note that division assumes Python 3, so may not work with Python 2.
      * Depends on numpy libary for the arrays.
      * If lists are passed, they are converted to numpy arrays (and back again).
      * Depends on scipy library for scipy.stats.f function.
 
     Note:
+    -----
     There are pathological cases where, for certain
     coefficient vectors (which result in certain cumulant values), the
     Wood F method will be unable to match moments (cumulants) with the
@@ -275,6 +289,7 @@ def wf(coeff, x):
 
 
     Examples:
+    ---------
     #Examples taken from Table 18.6 in N. L. Johnson, S. Kotz, N. Balakrishnan.
     #Continuous Univariate Distributions, Volume 1, John Wiley & Sons, 1994.
 
@@ -303,7 +318,7 @@ def wf(coeff, x):
     wf([0.9], 1) 
 
     References:
-
+    -----------
      * A. T. A. Wood. An F approximation to the distribution of a
        linear combination of chi-squared variables. Communications
        in Statistics-Simulation and Computation, 18(4):1439-1456,
@@ -364,6 +379,7 @@ def lpb4(coeff, x, p=4):
     random variables with the Wood F (WF) method.
 
     Parameters:
+    -----------
     coeff (list or numpy array): The coefficient vector. 
                                  All values must be greater than 0.
 
@@ -374,18 +390,21 @@ def lpb4(coeff, x, p=4):
 
 
     Returns:
+    --------
     The cdf of the x value(s). It is returned as the same type as x, 
     i.e. if x is a list, it is returned as a list; if x is a numpy array
     it is returned as a numpy array.
 
 
     Details:
+    --------
      * Note that division assumes Python 3, so may not work with Python 2.
      * Depends on numpy libary for the arrays.
      * If lists are passed, they are converted to numpy arrays (and back again).
      * Depends on scipy library for scipy.stats.f function.
 
     Note:
+    -----
     The coefficient vector must of length at least four if default p=4. In
     some cases when the coefficient vector was of length two or three,
     the algorithm would be unable to find roots of a particular
@@ -395,6 +414,7 @@ def lpb4(coeff, x, p=4):
 
 
     Examples:
+    ---------
     #Examples taken from Table 18.6 in N. L. Johnson, S. Kotz, N. Balakrishnan.
     #Continuous Univariate Distributions, Volume 1, John Wiley & Sons, 1994.
 
@@ -427,7 +447,7 @@ def lpb4(coeff, x, p=4):
 
 
     References:
-
+    -----------
      * B. G. Lindsay, R. S. Pilla, and P. Basak. Moment-based
        approximations of distributions using mixtures: Theory and
        applications. Annals of the Institute of Statistical Mathematics, 
@@ -459,6 +479,8 @@ def lpb4(coeff, x, p=4):
         message = "Pathological case, less than " + str(p) + " : running hbe instead."
         warnings.warn(message)
         mixed_pval_vec = hbe(coeff, x)
+        if isList:
+            mixed_pval_vec = mixed_pval_vec.tolist()
         return(mixed_pval_vec)
 
     #----------------------------------------------------------------#
